<?php
/**
 * Defines customizer options
 *
 * @package Customizer Library Demo
 */

function customizer_library_demo_options() {

	// Theme defaults
	$primary_color = '#5bc08c';
	$secondary_color = '#666';

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// More Examples
	$section = 'examples';

	// Arrays 

	$layout_choices = array(
		'choice-1' => 'Responsive Layout',
		'choice-2' => 'Fixed Layout'
	);

	$coupon_position_choices = array(
		'choice-1' => 'Before Recent Posts section',
		'choice-2' => 'After Recent Posts section'
	);

	$coupon_style_choices = array(
		'choice-1' => 'Hidden and click to reveal',
		'choice-2' => 'Visible for all visitors'
	);

	$sections[] = array(
		'id' => $section,
		'title' => __( 'Theme Settings', 'starter' ),
		'priority' => '10'
	);

	$options['logo'] = array(
		'id' => 'logo',
		'label'   => __( 'Logo', 'starter' ),
		'section' => $section,
		'type'    => 'image',
		'default' => get_template_directory_uri().'/assets/img/logo.png'
	);

	$options['site-layout'] = array(
		'id' => 'site-layout',
		'label'   => __( 'Site Layout', 'starter' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $layout_choices,
		'default' => 'choice-1'
	);

	$options['sticky-nav-on'] = array(
		'id' => 'sticky-nav-on',
		'label'   => __( 'Sticky header navigation', 'starter' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);		

	$options['header-search-on'] = array(
		'id' => 'header-search-on',
		'label'   => __( 'Display header search form', 'starter' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['featured-content-on'] = array(
		'id' => 'featured-content-on',
		'label'   => __( 'Display featured content on homepage', 'starter' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['featured-coupons-on'] = array(
		'id' => 'featured-coupons-on',
		'label'   => __( 'Display featured coupons on homepage', 'starter' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['featured-coupons-position'] = array(
		'id' => 'featured-coupons-position',
		'label'   => __( 'Featured coupons section position', 'starter' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $coupon_position_choices,		
		'default' => 'choice-1',
	);	

	$options['featured-coupons-heading'] = array(
		'id' => 'featured-coupons-heading',
		'label'   => __( 'Featured coupons section heading', 'starter' ),
		'section' => $section,
		'type'    => 'text',
		'default' => 'Exclusive Coupon Codes',		
	);

	$options['featured-coupons-num'] = array(
		'id' => 'featured-coupons-num',
		'label'   => __( 'Number of featured coupons to show', 'starter' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '3'
	);			

	$options['coupons-page-desc'] = array(
		'id' => 'coupons-page-desc',
		'label'   => __( 'Coupons page description', 'starter' ),
		'section' => $section,
		'type'    => 'textarea',
		'default' => 'You may enter description for the coupon page here.',		
	);

	$options['coupon-style'] = array(
		'id' => 'coupon-style',
		'label'   => __( 'How coupons displayed on single coupon page', 'starter' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $coupon_style_choices,
		'default' => 'choice-1'
	);			

	$options['home-content-heading'] = array(
		'id' => 'home-content-heading',
		'label'   => __( 'Recent posts section heading', 'starter' ),
		'section' => $section,
		'type'    => 'text',
		'default' => 'From the blog',		
	);

	$options['entry-excerpt-length'] = array(
		'id' => 'entry-excerpt-length',
		'label'   => __( 'Number of words to show on excerpt', 'starter' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '38',		
	);

	$options['single-share-on'] = array(
		'id' => 'single-share-on',
		'label'   => __( 'Display share icons on single posts', 'starter' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['author-box-on'] = array(
		'id' => 'author-box-on',
		'label'   => __( 'Display author box on single posts', 'starter' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	
	$options['related-posts-on'] = array(
		'id' => 'related-posts-on',
		'label'   => __( 'Display related posts on single posts', 'starter' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['footer-widgets-on'] = array(
		'id' => 'footer-widgets-on',
		'label'   => __( 'Display footer widgets', 'starter' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['back-top-on'] = array(
		'id' => 'back-top-on',
		'label'   => __( 'Display "back to top" icon link on the site bottom', 'starter' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['footer-credit'] = array(
		'id' => 'footer-credit',
		'label'   => __( 'Customize Site Footer Text/Link', 'starter' ),
		'section' => $section,
		'type'    => 'textarea',
		'default' => '&copy; ' . date("o") . ' <a href="' . home_url() .'">' . get_bloginfo('name') . '</a> - Theme by <a href="http://www.20script.ir" target="_blank">20Script</a>'
	);			

	//$options['example-range'] = array(
	//	'id' => 'example-range',
	//	'label'   => __( 'Example Range Input', 'starter' ),
	//	'section' => $section,
	//	'type'    => 'range',
	//	'input_attrs' => array(
	//      'min'   => 0,
	//        'max'   => 10,
	//        'step'  => 1,
	//       'style' => 'color: #0a0',
	//	)
	//);

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

	// To delete custom mods use: customizer_library_remove_theme_mods();

}
add_action( 'init', 'customizer_library_demo_options' );